@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_kernel.c,v 1.8 2004/10/22 20:17:34 esteban Exp $
+$Id: gdisp_kernel.c,v 1.10 2005/03/25 23:42:08 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -344,6 +344,12 @@ gdisp_createKernel (gint    argc,
       gdisp_initPlotTextSystem(kernel,plotSystem);
       break;
 
+    case GD_PLOT_ORBITAL :
+#if _USE_OPENGL
+      gdisp_initOrbitalPlotSystem(kernel,plotSystem);
+#endif
+      break;
+
     default :
       break;
 
