@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_sampling.c,v 1.7 2004/10/15 10:07:33 tractobob Exp $
+$Id: gdisp_sampling.c,v 1.10 2004/11/17 09:29:36 dufy Exp $
 
 -----------------------------------------------------------------------
 
@@ -166,7 +166,7 @@ gdisp_computeTimerPeriod ( Kernel_T         *kernel,
   plotPeriod = (*plotSystemData->plotSystem->psGetPeriod)
                                       (kernel,plotSystemData->plotData);
 
-  *timerPeriod = MIN(*timerPeriod,plotPeriod);
+  *timerPeriod = gdisp_computePgcd(*timerPeriod,plotPeriod);
 
 }
 
@@ -665,7 +665,8 @@ gdisp_samplingThread (void *data )
       /*
        * Check out new incoming frame.
        */
-      if (sampleRefTimeTag != (guint)sampleValue.time) {
+      if (sampleRefTimeTag != 0 &&
+	  sampleRefTimeTag != (guint)sampleValue.time) {
 
 #if defined(SAMPLING_DEBUG)
 
@@ -676,9 +677,9 @@ gdisp_samplingThread (void *data )
 				  gdisp_treatSymbolOnOneGraphicPlot,
 				  (void*)NULL);
 
-	sampleRefTimeTag = (guint)sampleValue.time;
-
       }
+      
+      sampleRefTimeTag = (guint)sampleValue.time;
 
       /*
        * Treat symbol.
