@@ -1,6 +1,6 @@
 /*!  \file 
  
-$Header: /cvsroot/tsp/tsp/src/core/include/tsp_const_def.h,v 1.24 2004/09/23 16:11:57 tractobob Exp $
+$Header: /cvsroot/tsp/tsp/src/core/include/tsp_const_def.h,v 1.28 2005/08/14 23:15:22 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -38,6 +38,14 @@ Purpose   : definitions and const that must have a program wide scope
 #define _TSP_CONST_DEF_H
 
 
+#define TSP_PROJECT_URL "https://savannah.nongnu.org/projects/tsp"
+/* 
+ * The following macro should be used to print-out TSP 
+ * versio in binary executable. We should find a way to 
+ * automatically change this when tagging... FIXME: erk
+ */
+#define TSP_SOURCE_VERSION "0.6.5"
+
 /** TSP Version */
 #define TSP_VERSION 1
 
@@ -225,7 +233,12 @@ typedef struct  TSP_otsp_server_info_t TSP_otsp_server_info_t;
 
 /*-------- RPC --------*/
 
+#ifdef BUILD_XMLRPC
+#define TSP_PROTOCOL "xmlrpc"
+#else
+#define TSP_PROTOCOL "rpc"
 #define TSP_RPC_PROTOCOL "rpc"
+#endif
 /**
  * base RPC PROG_ID that will be used 
  * to calculate the PROG ID for each server
@@ -244,6 +257,14 @@ typedef struct  TSP_otsp_server_info_t TSP_otsp_server_info_t;
  */
 #define TSP_MAXHOSTNAMELEN 255
 
+/* ------- URL LENGTH ----*/
+
+/**
+ * Max url length, 4096 looks like a sane value
+ * see http://www.faqts.com/knowledge_base/view.phtml/aid/329
+ */
+#define TSP_MAX_URL_LENGTH 4096
+
 /*-------- MACROS --------*/
 
 #define TSP_CHECK_ALLOC(p, ret) \
