@@ -1,12 +1,13 @@
 /*!  \file 
 
-$Header: /cvsroot/tsp/tsp/src/core/rpc/tsp_server.c,v 1.19 2004/10/28 20:10:44 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/core/rpc/tsp_server.c,v 1.22 2005/06/26 16:01:47 erk Exp $
 
 -----------------------------------------------------------------------
 
 TSP Library - core components for a generic Transport Sampling Protocol.
 
 Copyright (c) 2002 Yves DUFRENNE, Stephane GALLES, Eric NOULARD and Robert PAGNOT 
+Copyright (c) 2005 Cesare BERTONA
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
@@ -201,15 +202,6 @@ static int TSP_rpc_init(TSP_rpc_request_config_t *config)
 
   STRACE_IO(("-->IN"));
 
-#ifdef VXWORKS
-  if(rpcTaskInit() == ERROR)
-    {
-      config->server_number = -1;
-      STRACE_IO(("-->OUT "));
-      return config->server_number;
-    }
-#endif
-
   /* look for a free port */
   while(rpcport && config->server_number<TSP_MAX_SERVER_NUMBER)
     {
@@ -231,8 +223,8 @@ static void TSP_rpc_run(TSP_rpc_request_config_t *config)
   int32_t rpc_progid = TSP_get_progid(config->server_number);
 
   /* svc_create does not exist for linux, we must use the deprecated function */
-  //pmap_unset (rpc_progid, TSP_RPC_VERSION_INITIAL);
-	
+  /* pmap_unset (rpc_progid, TSP_RPC_VERSION_INITIAL); */
+
   config->xprt = svctcp_create(RPC_ANYSOCK, 0, 0);
   if (config->xprt == NULL) 
     {
@@ -256,8 +248,8 @@ static void TSP_rpc_run(TSP_rpc_request_config_t *config)
 
 static void TSP_rpc_stop(TSP_rpc_request_config_t *config)
 {
-  //STRACE_DEBUG(("calling svc_exit..."));
-  //svc_destroy(config->xprt);
+  /* STRACE_DEBUG(("calling svc_exit...")); */
+  /* svc_destroy(config->xprt); */
 
   /* Clean-up Port map so that next provider could use this ProgId */
   if(config->server_number >= 0)
@@ -324,7 +316,7 @@ void* TSP_rpc_request_run(TSP_provider_request_handler_t* this)
 
   STRACE_IO(("-->IN"));  
  
-  //pthread_detach(pthread_self()); /* FIXME shoudl we do this */
+  /* pthread_detach(pthread_self()); */ /* FIXME shoudl we do this */ 
 
   if(config->server_number >= 0)
     {
