@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_core.c,v 1.12 2005/02/23 17:28:11 dufy Exp $
+$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_core.c,v 1.15 2005/08/14 22:39:36 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -50,6 +50,7 @@ Purpose   : Blackboard Idiom implementation
 #include <sys/sem.h>
 #include <sys/msg.h>
 
+#include <tsp_abs_types.h>
 #include <bb_core.h>
 #include <bb_utils.h>
 #include "tsp_abs_types.h"
@@ -74,6 +75,24 @@ static const char* E_BB_2STRING[] = {"NoAType 0",
 				     "UserType",
 				     "NotAType end"};
 
+int32_t
+bb_check_version(volatile S_BB_T* bb) {
+  int32_t retval = 0;
+/*   union { */
+/*     uint16_t lower; */
+/*     uint16_t upper; */
+/*   } version_using, version_access; */
+
+  assert(bb);
+  retval = BB_VERSION_ID - bb->bb_version_id;
+/*   if (retval != 0) { */
+/*       bb_logMsg(BB_LOG_WARNING, "BlackBoard::bb_check_version", */
+/* 		"BB version mismatch using <0x%08X> for accessing <0x%08X>\n", */
+/* 		BB_VERSION_ID,bb->bb_version_id); */
+/*   } */
+  return retval;
+} /* end of bb_check_version */
+
 int32_t 
 bb_size(const int32_t n_data, const int32_t data_size) {
   /* The SHM segment is sized to:
@@ -199,6 +218,9 @@ bb_data_initialise(volatile S_BB_T* bb, S_BB_DATADESC_T* data_desc,void* default
     case E_BB_FLOAT:
       ((float*) data)[i] = default_value ? *((float *) default_value) : 0.0;
       break;
+    case E_BB_INT8:
+      ((int8_t*) data)[i] = default_value ? *((int8_t *) default_value) : 0;
+      break;
     case E_BB_INT16:
       ((int16_t*) data)[i] = default_value ? *((short *) default_value) : 0;
       break; 
@@ -207,7 +229,10 @@ bb_data_initialise(volatile S_BB_T* bb, S_BB_DATADESC_T* data_desc,void* default
       break; 
     case E_BB_INT64:
       ((int64_t*) data)[i] = default_value ? *((long *) default_value) : 0;
-      break; 
+      break;       
+    case E_BB_UINT8:
+      ((uint8_t*) data)[i] = default_value ? *((uint8_t *) default_value) : 0;
+      break;
     case E_BB_UINT16:
       ((uint16_t*) data)[i] = default_value ? *((unsigned short *) default_value) : 0;
       break;
@@ -263,6 +288,9 @@ bb_value_write(volatile S_BB_T* bb, S_BB_DATADESC_T data_desc,const char* value,
     case E_BB_FLOAT:
       ((float *)data)[idx] = atof(value);
       break;
+    case E_BB_INT8:
+      ((int8_t*)data)[idx] = strtol(value,(char **)NULL,hexval ? 16 : 10);
+      break; 
     case E_BB_INT16:
       ((int16_t*)data)[idx] = strtol(value,(char **)NULL,hexval ? 16 : 10);
       break; 
@@ -272,6 +300,9 @@ bb_value_write(volatile S_BB_T* bb, S_BB_DATADESC_T data_desc,const char* value,
     case E_BB_INT64:
       ((int64_t*)data)[idx] = strtoll(value,(char **)NULL,hexval ? 16 : 10);
       break; 
+    case E_BB_UINT8:
+      ((uint8_t*)data)[idx] = strtol(value,(char **)NULL,hexval ? 16 : 10);
+      break; 
     case E_BB_UINT16:
       ((uint16_t*)data)[idx] = strtoul(value,(char **)NULL,hexval ? 16 : 10);
       break;
@@ -357,6 +388,9 @@ bb_value_print(volatile S_BB_T* bb, S_BB_DATADESC_T data_desc, FILE* pf, int32_t
     case E_BB_FLOAT:
       fprintf(pf,"%f ",((float*) data)[i]);
       break;
+    case E_BB_INT8:
+      fprintf(pf,"%d ",((int8_t*) data)[i]);
+      break;
     case E_BB_INT16:
       fprintf(pf,"%d ",((int16_t*) data)[i]);
       break; 
@@ -365,6 +399,9 @@ bb_value_print(volatile S_BB_T* bb, S_BB_DATADESC_T data_desc, FILE* pf, int32_t
       break; 
     case E_BB_INT64:
       fprintf(pf,"%lld ",((int64_t*) data)[i]);
+      break;
+    case E_BB_UINT8:
+      fprintf(pf,"0x%x ",((uint8_t*) data)[i]);
       break; 
     case E_BB_UINT16:
       fprintf(pf,"0x%x ",((uint16_t*) data)[i]);
@@ -473,6 +510,7 @@ bb_create(S_BB_T** bb,
   if (E_OK == retcode) {
     /* RAZ de la mmoire allouee */
     memset(*bb,0,mmap_size);        
+    (*bb)->bb_version_id = BB_VERSION_ID;
     strncpy((*bb)->name,pc_bb_name,BB_NAME_MAX_SIZE+1);
     (*bb)->max_data_desc_size = n_data;
     (*bb)->data_desc_offset = sizeof(S_BB_T);
